@@ -13,7 +13,7 @@ from mcdbot.helpers import check_user
 from mcdbot.mcdbot import Mcdbot
 
 
-async def unregister(main: Mcdbot, msg, player: str):
+async def unregister(main: Mcdbot, msg, context, player: str):
     if check_user(main, msg.author):
         if main.redis.user_get_mc_player(msg.author) == player:
             await main.redis.atomic_purge_mc_player(player, msg.author)
